@@ -1,4 +1,4 @@
-from celery.decorators import task
+from celery import task
 from celery.utils.log import get_task_logger
 from django.db.models import get_model
 import re
